function data = generate_1d1g1sr( model, m, n )

  if nargin < 1
    error( [ mfilename ' needs at least one input argument.' ] );
  end
  
  if ~exist( 'm', 'var' )
    m = 1;
  end
  
  if ~exist( 'n', 'var' )
    n = m;
  end
  
  % Check that "model" has all required fields
  model = check_1d1g1sr_model( model );
  
  % Prepare output
  
  data = repmat( NaN, m, n );
  
  % For each sample: which class?
  
  which_class = ( rand( m, n ) > model.b0 );
  
  % For each sample in class 0 (silence): which component of the mixture?
  % ( 0: Dirac, 1: Gamma )
  
  ind_class0 = find( which_class == 0 );
  which_component = ( rand( size( ind_class0 ) ) > model.w0d );
  
  
  % Now we can generate data
  
  % class 0: Dirac component
  
  data( ind_class0( which_component == 0 ) ) = 0;
  
  % class 0: Gamma component
  
  ind = ind_class0( which_component == 1 );
  data( ind ) = gamrnd( model.gamma0, model.beta0, size( ind, 1 ), size( ind, 2 ) );
  
  % class 1: Shifted Rice
  
  a_shift = shift_1d1g1sr( model.gamma0, model.beta0 );
  ind_class1 = find( which_class == 1 );
  data( ind_class1 ) = a_shift + my_ricernd( model.sigma1, model.V1, size( ind_class1, 1 ), size( ind_class1, 2 ) );
  
  
  % Sanity check
  
  if any( isnan( data(:) ) )
    error( [ mfilename ' has a NaN-insanity!' ] );
  end
  