function x = my_riceinv( p, sigma, V, npoints )
  
  if nargin < 2
    error( [ mfilename ' needs at least 2 input arguments.' ] );
  end
  
  if any( p<0 ) | any( p>1 )
    error( [ mfilename ': all values in "p" must lie in the [0 1] interval (probabilities).' ] );
  end

  if sigma < 0
    error( [ mfilename ': "sigma" must be >0.' ] );
  end
  
  if ~exist( 'V', 'var' )    V = 0;  end
  if ~exist( 'npoints', 'var' )  npoints = 100000; end;
  
  V = abs( V );
  
  if prod( size( sigma ) ) > 1    error( [ '"sigma" must be a scalar only' ] );  end;
  if prod( size( V ) ) > 1    error( [ '"V" must be a scalar only' ] );  end;
    
  a_rms = sqrt( V ^ 2 + 2 * sigma ^ 2 );
  
  point_list = (1:npoints)/npoints*8*a_rms;
  
  pdf_list = my_ricepdf( point_list, sigma, V );
  cdf_list = cumsum( diff( [ 0 point_list ] ) .* pdf_list );
  
  % Sanity check: do we reach close to one?
  if abs( 1 - cdf_list( end ) ) > 1 / npoints
    error( [ mfilename ' is not to be trusted this time!' ] );
  end
  
  cdf_list = cdf_list / max( cdf_list );
  
  [ cdf_list, ind ] = unique( cdf_list );
  point_list = point_list( ind );
  
  p_size = size( p );
  
  x = interp1( cdf_list, point_list, p, 'linear' );
  