function s060307_run_cc_analysis( basedir, recording_list )
  
  if nargin < 2
    error( [ mfilename ' needs 2 input argument.' ] );
  end
  
  n_rec = numel( recording_list );
  
  for a = 1:n_rec
    
    recording_name = recording_list{ a };

    disp( ' ' );
    
    % Check for output file
    
    out_filename = fullfile( basedir, recording_name, [ mfilename '-' recording_name '.mat' ] );
    
    if exist( out_filename, 'file' )
      
      disp( [ mfilename ': output file already exists. Skipping it.' ] );
      disp( [ '  "' out_filename '"' ] );
      
    else
      
      a_dir = fullfile( basedir, recording_name );
      
      % Define input files
      
      video_filename_list = cell( 3, 1 );
      
      for a = 1:3
      
	video_filename_list{ a } = fullfile( a_dir, [ recording_name sprintf( '_cam%d_video_motion2_24_32.mat', a ) ] );
      
      end
      
      base_audio_filename =  fullfile( a_dir, [ recording_name '_array1_ssm_result.mat' ] );
      
      audio_filename = fullfile( a_dir, [ 's060307_fit_audio_model_' recording_name '_array1_ssm_result.mat' ] );
      
      audio_start_time = 10.0;
      
      % Check that all input files exist
      
      all_input_file_list = { video_filename_list{:}, base_audio_filename };
      
      all_input_ready     = 1;
      
      for a = 1:numel( all_input_file_list )
	
	if ~exist( all_input_file_list{ a }, 'file' )
	  all_input_ready = 0;
	  break
	end
	
	d = dir( all_input_file_list{ a } );
	
	if d.isdir
	  disp( [ mfilename ': cannot process: the following one should be a file, but it is a directory.' ] );
	  disp( d.name );
	  all_input_ready = 0;
	  break
	end
	
	if d.bytes < 10
	  disp( [ mfilename ': cannot process. Empty input file:' ] );
	  disp( [ '  "' d.name '"' ] );
	  all_input_ready = 0;
	  break
	end
	
      end
      
      if all_input_ready
      
	disp( [ mfilename ': starting processing a recording. The output file will be:' ] );
	disp( [ '  "' out_filename '"' ] );
	disp( ' ' );
	
	% Create it to lock it from other computers
	
	fid = fopen( out_filename, 'wt' );
	fclose( fid );
	
	% Do the processing
	
	cc_result = s060307_cc_analysis( video_filename_list, audio_filename, audio_start_time );
	
	save( out_filename, 'cc_result' );
	
	disp( [ mfilename ': finished processing recording "' recording_name '". Wrote out output file.' ] );
	disp( [ '  "' out_filename '"' ] );
	
      end % Check for input
      
    end % Check for output
    
  end % Loop through AV16.3 recordings
  